'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-64113c20.js');
const debounce = require('./debounce-077ed402.js');
const index_esm_min = require('./index.esm.min-df701fa5.js');
const index_esm_min$1 = require('./index.esm.min-4e00042e.js');
const sdkRedux = require('@boldpenguin/sdk-redux');
const isEqual = require('./isEqual-fa4ca97c.js');
const _baseUniq = require('./_baseUniq-b5aba718.js');
const store = require('./store-fe3d3434.js');
require('./_commonjsHelpers-bcc1208a.js');

/**
 * A faster alternative to `Function#apply`, this function invokes `func`
 * with the `this` binding of `thisArg` and the arguments of `args`.
 *
 * @private
 * @param {Function} func The function to invoke.
 * @param {*} thisArg The `this` binding of `func`.
 * @param {Array} args The arguments to invoke `func` with.
 * @returns {*} Returns the result of `func`.
 */
function apply(func, thisArg, args) {
  switch (args.length) {
    case 0: return func.call(thisArg);
    case 1: return func.call(thisArg, args[0]);
    case 2: return func.call(thisArg, args[0], args[1]);
    case 3: return func.call(thisArg, args[0], args[1], args[2]);
  }
  return func.apply(thisArg, args);
}

var _apply = apply;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax = Math.max;

/**
 * A specialized version of `baseRest` which transforms the rest array.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @param {number} [start=func.length-1] The start position of the rest parameter.
 * @param {Function} transform The rest array transform.
 * @returns {Function} Returns the new function.
 */
function overRest(func, start, transform) {
  start = nativeMax(start === undefined ? (func.length - 1) : start, 0);
  return function() {
    var args = arguments,
        index = -1,
        length = nativeMax(args.length - start, 0),
        array = Array(length);

    while (++index < length) {
      array[index] = args[start + index];
    }
    index = -1;
    var otherArgs = Array(start + 1);
    while (++index < start) {
      otherArgs[index] = args[index];
    }
    otherArgs[start] = transform(array);
    return _apply(func, this, otherArgs);
  };
}

var _overRest = overRest;

/**
 * Creates a function that returns `value`.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {*} value The value to return from the new function.
 * @returns {Function} Returns the new constant function.
 * @example
 *
 * var objects = _.times(2, _.constant({ 'a': 1 }));
 *
 * console.log(objects);
 * // => [{ 'a': 1 }, { 'a': 1 }]
 *
 * console.log(objects[0] === objects[1]);
 * // => true
 */
function constant(value) {
  return function() {
    return value;
  };
}

var constant_1 = constant;

var defineProperty = (function() {
  try {
    var func = isEqual._getNative(Object, 'defineProperty');
    func({}, '', {});
    return func;
  } catch (e) {}
}());

var _defineProperty = defineProperty;

/**
 * The base implementation of `setToString` without support for hot loop shorting.
 *
 * @private
 * @param {Function} func The function to modify.
 * @param {Function} string The `toString` result.
 * @returns {Function} Returns `func`.
 */
var baseSetToString = !_defineProperty ? _baseUniq.identity_1 : function(func, string) {
  return _defineProperty(func, 'toString', {
    'configurable': true,
    'enumerable': false,
    'value': constant_1(string),
    'writable': true
  });
};

var _baseSetToString = baseSetToString;

/** Used to detect hot functions by number of calls within a span of milliseconds. */
var HOT_COUNT = 800,
    HOT_SPAN = 16;

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeNow = Date.now;

/**
 * Creates a function that'll short out and invoke `identity` instead
 * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
 * milliseconds.
 *
 * @private
 * @param {Function} func The function to restrict.
 * @returns {Function} Returns the new shortable function.
 */
function shortOut(func) {
  var count = 0,
      lastCalled = 0;

  return function() {
    var stamp = nativeNow(),
        remaining = HOT_SPAN - (stamp - lastCalled);

    lastCalled = stamp;
    if (remaining > 0) {
      if (++count >= HOT_COUNT) {
        return arguments[0];
      }
    } else {
      count = 0;
    }
    return func.apply(undefined, arguments);
  };
}

var _shortOut = shortOut;

/**
 * Sets the `toString` method of `func` to return `string`.
 *
 * @private
 * @param {Function} func The function to modify.
 * @param {Function} string The `toString` result.
 * @returns {Function} Returns `func`.
 */
var setToString = _shortOut(_baseSetToString);

var _setToString = setToString;

/**
 * The base implementation of `_.rest` which doesn't validate or coerce arguments.
 *
 * @private
 * @param {Function} func The function to apply a rest parameter to.
 * @param {number} [start=func.length-1] The start position of the rest parameter.
 * @returns {Function} Returns the new function.
 */
function baseRest(func, start) {
  return _setToString(_overRest(func, start, _baseUniq.identity_1), func + '');
}

var _baseRest = baseRest;

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/**
 * The base implementation of methods like `_.difference` without support
 * for excluding multiple arrays or iteratee shorthands.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {Array} values The values to exclude.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 */
function baseDifference(array, values, iteratee, comparator) {
  var index = -1,
      includes = _baseUniq._arrayIncludes,
      isCommon = true,
      length = array.length,
      result = [],
      valuesLength = values.length;

  if (!length) {
    return result;
  }
  if (iteratee) {
    values = _baseUniq._arrayMap(values, isEqual._baseUnary(iteratee));
  }
  if (comparator) {
    includes = _baseUniq._arrayIncludesWith;
    isCommon = false;
  }
  else if (values.length >= LARGE_ARRAY_SIZE) {
    includes = isEqual._cacheHas;
    isCommon = false;
    values = new isEqual._SetCache(values);
  }
  outer:
  while (++index < length) {
    var value = array[index],
        computed = iteratee == null ? value : iteratee(value);

    value = (comparator || value !== 0) ? value : 0;
    if (isCommon && computed === computed) {
      var valuesIndex = valuesLength;
      while (valuesIndex--) {
        if (values[valuesIndex] === computed) {
          continue outer;
        }
      }
      result.push(value);
    }
    else if (!includes(values, computed, comparator)) {
      result.push(value);
    }
  }
  return result;
}

var _baseDifference = baseDifference;

/** Built-in value references. */
var spreadableSymbol = isEqual._Symbol ? isEqual._Symbol.isConcatSpreadable : undefined;

/**
 * Checks if `value` is a flattenable `arguments` object or array.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.
 */
function isFlattenable(value) {
  return isEqual.isArray_1(value) || isEqual.isArguments_1(value) ||
    !!(spreadableSymbol && value && value[spreadableSymbol]);
}

var _isFlattenable = isFlattenable;

/**
 * The base implementation of `_.flatten` with support for restricting flattening.
 *
 * @private
 * @param {Array} array The array to flatten.
 * @param {number} depth The maximum recursion depth.
 * @param {boolean} [predicate=isFlattenable] The function invoked per iteration.
 * @param {boolean} [isStrict] Restrict to values that pass `predicate` checks.
 * @param {Array} [result=[]] The initial result value.
 * @returns {Array} Returns the new flattened array.
 */
function baseFlatten(array, depth, predicate, isStrict, result) {
  var index = -1,
      length = array.length;

  predicate || (predicate = _isFlattenable);
  result || (result = []);

  while (++index < length) {
    var value = array[index];
    if (depth > 0 && predicate(value)) {
      if (depth > 1) {
        // Recursively flatten arrays (susceptible to call stack limits).
        baseFlatten(value, depth - 1, predicate, isStrict, result);
      } else {
        isEqual._arrayPush(result, value);
      }
    } else if (!isStrict) {
      result[result.length] = value;
    }
  }
  return result;
}

var _baseFlatten = baseFlatten;

/**
 * The base implementation of methods like `_.xor`, without support for
 * iteratee shorthands, that accepts an array of arrays to inspect.
 *
 * @private
 * @param {Array} arrays The arrays to inspect.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of values.
 */
function baseXor(arrays, iteratee, comparator) {
  var length = arrays.length;
  if (length < 2) {
    return length ? _baseUniq._baseUniq(arrays[0]) : [];
  }
  var index = -1,
      result = Array(length);

  while (++index < length) {
    var array = arrays[index],
        othIndex = -1;

    while (++othIndex < length) {
      if (othIndex != index) {
        result[index] = _baseDifference(result[index] || array, arrays[othIndex], iteratee, comparator);
      }
    }
  }
  return _baseUniq._baseUniq(_baseFlatten(result, 1), iteratee, comparator);
}

var _baseXor = baseXor;

/**
 * This method is like `_.isArrayLike` except that it also checks if `value`
 * is an object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array-like object,
 *  else `false`.
 * @example
 *
 * _.isArrayLikeObject([1, 2, 3]);
 * // => true
 *
 * _.isArrayLikeObject(document.body.children);
 * // => true
 *
 * _.isArrayLikeObject('abc');
 * // => false
 *
 * _.isArrayLikeObject(_.noop);
 * // => false
 */
function isArrayLikeObject(value) {
  return isEqual.isObjectLike_1(value) && isEqual.isArrayLike_1(value);
}

var isArrayLikeObject_1 = isArrayLikeObject;

/**
 * Gets the last element of `array`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to query.
 * @returns {*} Returns the last element of `array`.
 * @example
 *
 * _.last([1, 2, 3]);
 * // => 3
 */
function last(array) {
  var length = array == null ? 0 : array.length;
  return length ? array[length - 1] : undefined;
}

var last_1 = last;

/**
 * This method is like `_.xor` except that it accepts `comparator` which is
 * invoked to compare elements of `arrays`. The order of result values is
 * determined by the order they occur in the arrays. The comparator is invoked
 * with two arguments: (arrVal, othVal).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 * @example
 *
 * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
 * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
 *
 * _.xorWith(objects, others, _.isEqual);
 * // => [{ 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
 */
var xorWith = _baseRest(function(arrays) {
  var comparator = last_1(arrays);
  comparator = typeof comparator == 'function' ? comparator : undefined;
  return _baseXor(isEqual._arrayFilter(arrays, isArrayLikeObject_1), undefined, comparator);
});

var xorWith_1 = xorWith;

const bpSdkDynamicInputEventContainerCss = "";

const BpSdkDynamicInputEventContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.saveAnswer = index.createEvent(this, "saveAnswer", 7);
    this.removeActiveAnswer = index.createEvent(this, "removeActiveAnswer", 7);
    this.SAVE_ANSWER_DEBOUNCE_MS = 500;
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        configOptions: sdkRedux.getConfigOptions(state),
      };
    };
    this.debouncedEmit = debounce.debounce_1(this.emitSaveAnswer, this.SAVE_ANSWER_DEBOUNCE_MS);
    this.onFocusIn = () => {
      var _a, _b, _c;
      if (this.inputComponentType === index_esm_min.t.DropDown && !((_b = (_a = this.answer) === null || _a === void 0 ? void 0 : _a.question) === null || _b === void 0 ? void 0 : _b.multiple)) {
        this.removeActiveAnswer.emit();
      }
      else {
        this.updateActiveAnswerId((_c = this.answer) === null || _c === void 0 ? void 0 : _c.id);
      }
    };
    this.onFocusOut = () => {
      this.touched = true;
      if (this.hasPendingUpdate) {
        this.emitSaveAnswer(this.lastAnswer);
      }
      this.determineErrors(this.errors, this.touched, this.pristine);
    };
    this.answer = undefined;
    this.shouldHideLabel = false;
    this.useSelectAlias = false;
    this.showBusinessClassificationSelector = false;
    this.errors = undefined;
    this.label = undefined;
    this.labelledBy = undefined;
    this.updateActiveAnswerId = undefined;
    this.updateErrors = undefined;
    this.referenceTypes = index_esm_min.ue;
    this.configOptions = undefined;
    this.fieldType = '';
    this.isCoverageType = true;
    this.labelId = 'a11y-';
    this.isLabelledField = false;
    this.inputComponentType = undefined;
    this._label = '';
    this.lastAnswer = undefined;
    this.touched = false;
    this.pristine = true;
    this.useExternal = false;
    this.isDropdown = true;
    this.isNumeric = false;
    this._errors = [];
    this.hasPendingUpdate = false;
    this.debounceTime = undefined;
  }
  resetState() {
    var _a;
    this.lastAnswer = undefined;
    this.touched = false;
    this.pristine = true;
    this.answerId = (_a = this.answer) === null || _a === void 0 ? void 0 : _a.id;
    this.debouncedEmit.cancel();
    this.debounceTime = undefined;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  onAnswerChange(answer) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const code = (_b = (_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.code) !== null && _b !== void 0 ? _b : '';
    const id = (_c = answer === null || answer === void 0 ? void 0 : answer.id) !== null && _c !== void 0 ? _c : '';
    const fieldType = (_e = (_d = answer === null || answer === void 0 ? void 0 : answer.question) === null || _d === void 0 ? void 0 : _d.field_type) !== null && _e !== void 0 ? _e : '';
    const referenceType = (_g = (_f = answer === null || answer === void 0 ? void 0 : answer.question) === null || _f === void 0 ? void 0 : _f.reference_type) !== null && _g !== void 0 ? _g : '';
    this.fieldType = fieldType;
    this.isCoverageType = index_esm_min.ue.includes(referenceType);
    this.labelId = `a11y-${code}-${id}`;
    this.isLabelledField = index_esm_min.pe.labelledFields.includes(fieldType) && !this.isCoverageType;
    this.inputComponentType = this.getComponentType(fieldType);
    this.isDropdown = index_esm_min.pe.dropdownFields.includes(this.inputComponentType);
    this.isNumeric = index_esm_min.pe.numberFields.includes(fieldType);
    this.updateLabel(answer === null || answer === void 0 ? void 0 : answer.question, this.label, this.shouldHideLabel);
    // Sometimes components are reused without being disconnected,
    // so we need to reset state if the answer id is different
    if (((_h = this.answer) === null || _h === void 0 ? void 0 : _h.id) !== this.answerId) {
      this.resetState();
    }
  }
  onHideLabelChange(shouldHideLabel) {
    var _a;
    this.updateLabel((_a = this.answer) === null || _a === void 0 ? void 0 : _a.question, this.label, shouldHideLabel);
  }
  onLabelChange(label) {
    var _a;
    this.updateLabel((_a = this.answer) === null || _a === void 0 ? void 0 : _a.question, label, this.shouldHideLabel);
  }
  onConfigOptionsChange(options) {
    if (options.debounceTime !== this.debounceTime) {
      this.debounceTime = options.debounceTime;
    }
  }
  setDebounceTime(fieldType) {
    var _a, _b;
    this.SAVE_ANSWER_DEBOUNCE_MS = ['dropdown', 'radio', 'checkbox', 'dialog', 'selector'].includes(fieldType)
      ? 50
      : (_b = (_a = this.configOptions) === null || _a === void 0 ? void 0 : _a.debounceTime) !== null && _b !== void 0 ? _b : 500;
    this.debouncedEmit.cancel();
    this.debouncedEmit = debounce.debounce_1(this.emitSaveAnswer, this.SAVE_ANSWER_DEBOUNCE_MS);
  }
  updateLabel(question, label, shouldHideLabel) {
    var _a;
    if (!shouldHideLabel) {
      this._label = (_a = (label || (question === null || question === void 0 ? void 0 : question.text))) !== null && _a !== void 0 ? _a : '';
    }
    else {
      this._label = '';
    }
  }
  onErrorsChange(errors, oldErrors) {
    if (JSON.stringify(errors) !== JSON.stringify(oldErrors)) {
      this.determineErrors(errors, this.touched, this.pristine);
    }
  }
  onTouchedChange(touched, oldValue) {
    if (touched !== oldValue) {
      this.determineErrors(this.errors, touched, this.pristine);
    }
  }
  onPristineChange(pristine, oldValue) {
    if (pristine !== oldValue) {
      this.determineErrors(this.errors, this.touched, pristine);
    }
  }
  determineErrors(errors, touched, pristine) {
    this._errors = touched && !pristine ? errors : [];
  }
  updateErrorState(answer) {
    var _a;
    this.pristine = false;
    const errors = index_esm_min$1._c(answer, index_esm_min$1.vc(answer));
    if (xorWith_1((_a = this.errors) !== null && _a !== void 0 ? _a : [], errors, isEqual.isEqual_1).length > 0) {
      this.updateErrors({ answer, errors });
    }
    this.errors = errors;
    this.determineErrors(this.errors, this.touched, this.pristine);
  }
  onMakeDirty() {
    this.touched = true;
    this.pristine = false;
  }
  makeDirty() {
    this.pristine = false;
  }
  onValueUpdate(event) {
    if (this.useExternal) {
      return;
    }
    const { detail } = event;
    if (index_esm_min$1.De(this.lastAnswer, detail)) {
      if (index_esm_min$1.OL(this.answer, detail)) {
        const answer = index_esm_min$1.xl(Object.assign({}, this.answer), detail);
        this.updateErrorState(answer);
        if (this.isDropdown) {
          this.removeActiveAnswer.emit();
        }
      }
      this.lastAnswer = detail;
      this.updateValue(detail);
    }
  }
  emitSaveAnswer(newValue) {
    if (this.hasPendingUpdate) {
      this.saveAnswer.emit({
        answer: Object.assign({}, this.answer),
        new_value: newValue,
      });
      this.hasPendingUpdate = false;
    }
  }
  unique(keys) {
    return Object.keys(keys
      .filter((key) => key != null)
      .reduce((acc, key) => (Object.assign(Object.assign({}, acc), { [key]: key })), {}));
  }
  cleanValue(value) {
    if (value == null) {
      return value;
    }
    else if (typeof value !== 'string' && Array.isArray(value)) {
      return this.unique(value);
    }
    else if (value &&
      (this.fieldType === index_esm_min.t.SocialSecurityNumber || this.fieldType === index_esm_min.t.FederalEmployeeIdentification)) {
      // NOTE: This is a very targeted fix for a bug with FEIN / SSN where the asterisk characters were getting stripped on
      // question set reload.
      // This regex will basically remove all characters that are not one of the following:
      //   a number (\d)
      //   a . character
      //   a - character
      //   a * character
      //
      // If we remove the star characters, then since the backend sends sensitive fields with * characters, the fields
      // will not be "valid" and can cause the user to not be able to edit and save previous question sets without re-entering
      // FEIN / SSN data.
      return value.replace(/[^\d.\*-]/g, '');
    }
    else if (value && this.isNumeric) {
      return value.replace(/[^\d.-]/g, '');
    }
    else if (typeof value === 'string' && !this.isCoverageType && !this.isDropdown) {
      const curlySingleQuoteRegex = /[\u2018\u2019]/g;
      const curlyDoubleQuoteRegex = /[\u201C\u201D]/g;
      return value.replace(curlySingleQuoteRegex, "'").replace(curlyDoubleQuoteRegex, '"');
    }
    else {
      return value;
    }
  }
  save(data) {
    this.hasPendingUpdate = true;
    this.debouncedEmit(data);
  }
  updateValue(data) {
    const sanitizedData = this.cleanValue(data);
    this.save(sanitizedData);
  }
  onUseExternalChange(useExternal) {
    if (!useExternal) {
      this.unloadFocusEvents();
    }
  }
  loadFocusEvents() {
    if (!this.useExternal) {
      this.el.addEventListener('focusin', this.onFocusIn);
      this.el.addEventListener('focusout', this.onFocusOut);
    }
  }
  unloadFocusEvents() {
    var _a, _b;
    (_a = this.el) === null || _a === void 0 ? void 0 : _a.removeEventListener('focusin', this.onFocusIn);
    (_b = this.el) === null || _b === void 0 ? void 0 : _b.removeEventListener('focusout', this.onFocusOut);
  }
  getComponentType(fieldType) {
    let componentType = fieldType;
    if (index_esm_min.pe.textFields.includes(fieldType)) {
      componentType = 'text';
    }
    else if (index_esm_min.pe.maskedFields.includes(fieldType)) {
      componentType = 'masked';
    }
    if (this.isCoverageType) {
      componentType = 'coverage_type';
    }
    return componentType;
  }
  componentWillLoad() {
    var _a;
    this.useExternal = !!customElements.get('bp-sdk-external-dynamic-input-event-container');
    customElements.whenDefined('bp-sdk-external-dynamic-input-event-container').then(() => {
      this.useExternal = true;
      this.unloadFocusEvents();
    });
    this.onAnswerChange(this.answer);
    this.updateLabel((_a = this.answer) === null || _a === void 0 ? void 0 : _a.question, this.label, this.shouldHideLabel);
    this.handleSubscriptions();
  }
  componentWillUpdate() {
    this.handleSubscriptions();
  }
  componentDidLoad() {
    this.loadFocusEvents();
  }
  disconnectedCallback() {
    this.unloadFocusEvents();
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-dynamic-input-event-container", { answer: this.answer, configOptions: this.configOptions, useSelectAlias: this.useSelectAlias, showBusinessClassificationSelector: this.showBusinessClassificationSelector, errors: this.errors, shouldHideLabel: this.shouldHideLabel, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, referenceTypes: this.referenceTypes, updateActiveAnswerId: this.updateActiveAnswerId, updateErrors: this.updateErrors }));
  }
  renderInternal() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22, _23, _24, _25, _26, _27, _28, _29, _30, _31, _32, _33;
    return (index.h("bp-sdk-dynamic-input", { answerId: (_a = this.answer) === null || _a === void 0 ? void 0 : _a.id, answerPoolId: (_b = this.answer) === null || _b === void 0 ? void 0 : _b.answer_pool_id, applicationFormId: (_c = this.answer) === null || _c === void 0 ? void 0 : _c.application_form_id, choiceId: (_d = this.answer) === null || _d === void 0 ? void 0 : _d.choice_id, choiceIds: (_e = this.answer) === null || _e === void 0 ? void 0 : _e.choice_ids, choices: (_g = (_f = this.answer) === null || _f === void 0 ? void 0 : _f.question) === null || _g === void 0 ? void 0 : _g.choices, code: (_j = (_h = this.answer) === null || _h === void 0 ? void 0 : _h.question) === null || _j === void 0 ? void 0 : _j.code, displayType: (_k = this.answer) === null || _k === void 0 ? void 0 : _k.display_type, errors: this.errors, errorText: (_m = (_l = this.answer) === null || _l === void 0 ? void 0 : _l.question) === null || _m === void 0 ? void 0 : _m.error_text, fieldType: (_p = (_o = this.answer) === null || _o === void 0 ? void 0 : _o.question) === null || _p === void 0 ? void 0 : _p.field_type, helpText: (_r = (_q = this.answer) === null || _q === void 0 ? void 0 : _q.question) === null || _r === void 0 ? void 0 : _r.help_text, answeredBySource: this.answeredBySource(), inputComponentType: this.inputComponentType, isAutocomplete: !!((_t = (_s = this.answer) === null || _s === void 0 ? void 0 : _s.question) === null || _t === void 0 ? void 0 : _t.autocomplete), isCompleted: !!((_u = this.answer) === null || _u === void 0 ? void 0 : _u.is_completed), isCoverageType: this.isCoverageType, isHidden: !!((_w = (_v = this.answer) === null || _v === void 0 ? void 0 : _v.question) === null || _w === void 0 ? void 0 : _w.is_hidden), isLabelledField: !!this.isLabelledField, isMultiple: !!((_y = (_x = this.answer) === null || _x === void 0 ? void 0 : _x.question) === null || _y === void 0 ? void 0 : _y.multiple), isReadOnly: !!((_z = this.answer) === null || _z === void 0 ? void 0 : _z.is_readonly) || !!((_1 = (_0 = this.answer) === null || _0 === void 0 ? void 0 : _0.question) === null || _1 === void 0 ? void 0 : _1.is_readonly), isRequired: !!(((_2 = this.answer) === null || _2 === void 0 ? void 0 : _2.required) || ((_4 = (_3 = this.answer) === null || _3 === void 0 ? void 0 : _3.question) === null || _4 === void 0 ? void 0 : _4.required)), isSensitive: !!((_6 = (_5 = this.answer) === null || _5 === void 0 ? void 0 : _5.question) === null || _6 === void 0 ? void 0 : _6.is_sensitive), isTrackable: !!((_8 = (_7 = this.answer) === null || _7 === void 0 ? void 0 : _7.question) === null || _8 === void 0 ? void 0 : _8.trackable), label: this._label, labelId: this.labelId, labelledBy: this.labelledBy, maxDate: (_10 = (_9 = this.answer) === null || _9 === void 0 ? void 0 : _9.question) === null || _10 === void 0 ? void 0 : _10.max_date, maxValue: (_12 = (_11 = this.answer) === null || _11 === void 0 ? void 0 : _11.question) === null || _12 === void 0 ? void 0 : _12.max_value, minDate: (_14 = (_13 = this.answer) === null || _13 === void 0 ? void 0 : _13.question) === null || _14 === void 0 ? void 0 : _14.min_date, minValue: (_16 = (_15 = this.answer) === null || _15 === void 0 ? void 0 : _15.question) === null || _16 === void 0 ? void 0 : _16.min_value, order: (_18 = (_17 = this.answer) === null || _17 === void 0 ? void 0 : _17.question) === null || _18 === void 0 ? void 0 : _18.order, pattern: (_20 = (_19 = this.answer) === null || _19 === void 0 ? void 0 : _19.question) === null || _20 === void 0 ? void 0 : _20.pattern, placeholder: (_22 = (_21 = this.answer) === null || _21 === void 0 ? void 0 : _21.question) === null || _22 === void 0 ? void 0 : _22.placeholder, pristine: this.pristine, questionId: (_24 = (_23 = this.answer) === null || _23 === void 0 ? void 0 : _23.question) === null || _24 === void 0 ? void 0 : _24.id, questionGroupId: (_26 = (_25 = this.answer) === null || _25 === void 0 ? void 0 : _25.question) === null || _26 === void 0 ? void 0 : _26.question_group_id, questionSetId: (_28 = (_27 = this.answer) === null || _27 === void 0 ? void 0 : _27.question) === null || _28 === void 0 ? void 0 : _28.question_set_id, referenceType: (_30 = (_29 = this.answer) === null || _29 === void 0 ? void 0 : _29.question) === null || _30 === void 0 ? void 0 : _30.reference_type, showBusinessClassificationSelector: this.showBusinessClassificationSelector, shouldShowInput: !!(this.answer && this.answer.active && this.answer.display_type === 'public' && this.answer.question), text: (_32 = (_31 = this.answer) === null || _31 === void 0 ? void 0 : _31.question) === null || _32 === void 0 ? void 0 : _32.text, touched: this.touched, useSelectAlias: this.useSelectAlias, value: (_33 = this.answer) === null || _33 === void 0 ? void 0 : _33.value }));
  }
  answeredBySource() {
    var _a, _b;
    if ((_a = this.answer) === null || _a === void 0 ? void 0 : _a.answered_by_consumer) {
      return 'Consumer';
    }
    return (_b = this.answer) === null || _b === void 0 ? void 0 : _b.answered_by_source;
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "answer": ["onAnswerChange"],
    "shouldHideLabel": ["onHideLabelChange"],
    "label": ["onLabelChange"],
    "configOptions": ["onConfigOptionsChange"],
    "fieldType": ["setDebounceTime"],
    "debounceTime": ["setDebounceTime"],
    "errors": ["onErrorsChange"],
    "touched": ["onTouchedChange"],
    "pristine": ["onPristineChange"],
    "useExternal": ["onUseExternalChange"]
  }; }
};
BpSdkDynamicInputEventContainer.style = bpSdkDynamicInputEventContainerCss;

const bpSdkDynamicInputReduxContainerCss = "";

const BpSdkDynamicInputReduxContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.errorsUpdate = index.createEvent(this, "errorsUpdate", 7);
    this.handleUpdateActiveAnswerId = (answerId) => {
      this.updateActiveAnswerId(answerId);
    };
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.store.mapDispatchToProps(this, {
          updateActiveAnswerId: sdkRedux.updateActiveAnswerId,
          updateErrors: sdkRedux.updateErrors,
        });
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        errorState: state.application.errors,
        activeId: state.application.questionSets.activeAnswerId,
      };
    };
    this.answer = undefined;
    this.label = undefined;
    this.labelledBy = undefined;
    this.useSelectAlias = false;
    this.showBusinessClassificationSelector = true;
    this.shouldHideLabel = false;
    this.errorState = {};
    this.activeId = '';
    this.isAccumulatorAnswer = false;
    this.updateAccumulatorErrors = undefined;
    this.code = undefined;
    this.errors = [];
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-dynamic-input-redux-container');
    customElements.whenDefined('bp-sdk-external-dynamic-input-redux-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onErrorsStateChange(this.errorState);
    this.onAnswerChange(this.answer);
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onErrorsStateChange(errorState) {
    this.getErrors(this.answer, errorState);
    this.errorsUpdate.emit(this.errors);
  }
  onAnswerChange(answer) {
    this.getErrors(answer, this.errorState);
  }
  getErrors(answer, errorsState) {
    var _a;
    this.errors = (_a = errorsState[answer === null || answer === void 0 ? void 0 : answer.id]) !== null && _a !== void 0 ? _a : [];
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-dynamic-input-redux-container", { activeId: this.activeId, answer: this.answer, errors: this.errors, errorState: this.errorState, isAccumulatorAnswer: this.isAccumulatorAnswer, label: this.label, labelledBy: this.labelledBy, shouldHideLabel: this.shouldHideLabel, showBusinessClassificationSelector: this.showBusinessClassificationSelector, updateActiveAnswerId: this.handleUpdateActiveAnswerId, updateAccumulatorErrors: this.updateAccumulatorErrors, updateErrors: this.updateErrors, useSelectAlias: this.useSelectAlias, code: this.code }));
  }
  renderInternal() {
    return (index.h("bp-sdk-dynamic-input-event-container", { answer: this.answer, errors: this.errors, label: this.label, labelledBy: this.labelledBy, shouldHideLabel: this.shouldHideLabel, showBusinessClassificationSelector: this.showBusinessClassificationSelector, updateActiveAnswerId: this.updateActiveAnswerId, updateErrors: this.updateErrors, useSelectAlias: this.useSelectAlias }));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "errorState": ["onErrorsStateChange"],
    "answer": ["onAnswerChange"]
  }; }
};
BpSdkDynamicInputReduxContainer.style = bpSdkDynamicInputReduxContainerCss;

exports.bp_sdk_dynamic_input_event_container = BpSdkDynamicInputEventContainer;
exports.bp_sdk_dynamic_input_redux_container = BpSdkDynamicInputReduxContainer;
