import { r as registerInstance, h, c as createEvent, g as getElement } from './index-8f8983b3.js';
import { getConfigOptions, removeQuestionPool, getFormId, getPartnerEngineConfig, getQuestionSets, loadYears, loadMakes, loadModels, loadConfigurations, loadSingleQuestionSet, loadSingleApplicationForm, selectVehicle, resetSelectedVehicle, loadFullVehicleOptions, setVehicleSelection, getVehicleOptionsYears, getVehicleSelectionState, getDisplayFriendlyVehicleOptionsSelection } from '@boldpenguin/sdk-redux';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { c, t, w, R, s, N } from './index.esm.min-44aaacc7.js';
import { n as nL, T as TL, o as oL, h as yL, j as A4, k as ac, l as $9, p as pL, s as b9, v as o4 } from './index.esm.min-11fd4158.js';
import { d as debounce_1 } from './debounce-a2ea4df9.js';
import { i as isEqual_1 } from './isEqual-9e749192.js';
import './_commonjsHelpers-5e4b1d1a.js';

const bpSdkAccordionCss = "";

const BpSdkAccordion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.mapStateToProps = (state) => {
      return {
        configOptions: getConfigOptions(state),
      };
    };
    this.questionGroup = undefined;
    this.startPanelExpanded = true;
    this.configOptions = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accordion');
    customElements.whenDefined('bp-sdk-external-accordion').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  handleSubscriptions() {
    if (canGetStore()) {
      if (this.storeUnsubscribe) {
        this.storeUnsubscribe();
      }
      store.mapStateToProps(this, this.mapStateToProps);
    }
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-accordion", { questionGroup: this.questionGroup, startPanelExpanded: this.startPanelExpanded, configOptions: this.configOptions }));
  }
  renderAnswer(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && h("bp-sdk-dynamic-input-redux-container", { answer: answer, id: `bp-sdk-question-group__${answer.question.id}` }),
      nestedGroupToRender && h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderInternal() {
    var _a, _b, _c, _d, _e;
    return (h("div", { class: "bp-sdk-accordion__container" }, !((_a = this.configOptions) === null || _a === void 0 ? void 0 : _a.hideNestedQuestionGroupLabels) && (h("bp-sdk-question-group-label", { labelId: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.groupId, label: ((_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.parentQuestionAnswer.value) || ((_d = this.questionGroup) === null || _d === void 0 ? void 0 : _d.parentQuestionAnswer.question.text) })), (_e = this.questionGroup) === null || _e === void 0 ? void 0 :
      _e.answers.map((answer) => this.renderAnswer(answer))));
  }
};
BpSdkAccordion.style = bpSdkAccordionCss;

const bpSdkAccumulationQuestionGroupCss = "[name='evanston_activity_inventory_percentage_total']{visibility:hidden}[name='evanston_activity_inventory_percentage_total']+bp-sdk-errors-container{display:none}";

const BpSdkAccumulationQuestionGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answers = [];
    this.label = undefined;
    this.labelledBy = undefined;
    this.warning = 'Percent of total operations must equal 100%';
    this.accumulator = undefined;
    this.buffer = undefined;
    this.showAccumulatorWarning = false;
    this.showAccumulatorErrors = false;
    this.useExternal = false;
  }
  onAnswersChange(answers) {
    this.accumulator = (answers || []).find((answer) => { var _a; return ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.reference_type) === c.Accumulator; });
  }
  onAccumulatorChange(accumulator) {
    const buffer = parseInt(accumulator === null || accumulator === void 0 ? void 0 : accumulator.value, 10);
    this.buffer = isNaN(buffer) ? undefined : buffer;
    this.showAccumulatorWarning = this.validateAccumulatorValue();
  }
  onAccumulatorErrorsChange({ detail }) {
    this.showAccumulatorErrors = detail.length > 0;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accumulation-question-group');
    customElements.whenDefined('bp-sdk-external-accumulation-question-group').then(() => {
      this.useExternal = true;
    });
    this.onAnswersChange(this.answers);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-accumulation-question-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy, warning: this.warning }));
  }
  shouldHideLabel(answer) {
    var _a, _b;
    return (((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.field_type) === t.CheckBox || ((_b = answer === null || answer === void 0 ? void 0 : answer.question) === null || _b === void 0 ? void 0 : _b.reference_type) === c.Accumulator);
  }
  getAriaLabel(answer) {
    var _a;
    return ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.field_type) === t.CheckBox ? answer.question.text : undefined;
  }
  validateAccumulatorValue() {
    var _a;
    if ((_a = this.accumulator) === null || _a === void 0 ? void 0 : _a.value) {
      return this.buffer < this.accumulator.question.min_value || this.buffer > this.accumulator.question.max_value;
    }
    return false;
  }
  renderInternal() {
    var _a;
    return (h("div", { class: "bp-sdk-accumulation-question-group__container" }, h("div", { class: "bp-sdk-accumulation-question-group__wrapper" }, h("div", { class: "bp-sdk-accumulation-question-set__header" }, h("bp-sdk-progress", { label: "Question group progress", value: this.buffer }), h("div", null, ((_a = this.accumulator) === null || _a === void 0 ? void 0 : _a.value) && (h("h2", { "aria-live": "assertive", class: "bp-sdk-accumulation-question-set__value" }, this.accumulator.value, "%")), this.showAccumulatorErrors && h("h4", { class: "bp-sdk-accumulation-question-set__error" }, this.warning), this.showAccumulatorWarning && !this.showAccumulatorErrors && (h("h4", { class: "bp-sdk-accumulation-question-set__warning" }, this.warning)))), this.answers.map((answer) => (h("bp-sdk-dynamic-input-redux-container", { class: nL('', {
        'bp-sdk-indent': answer.question.reference_type === c.Indent,
      }), answer: answer, shouldHideLabel: this.shouldHideLabel(answer), "aria-label": this.getAriaLabel(answer), isAccumulatorAnswer: answer.question.reference_type === c.Accumulator }))))));
  }
  static get watchers() { return {
    "answers": ["onAnswersChange"],
    "accumulator": ["onAccumulatorChange"]
  }; }
};
BpSdkAccumulationQuestionGroup.style = bpSdkAccumulationQuestionGroupCss;

const bpSdkAccumulationQuestionGroupContainerCss = "";

const BpSdkAccumulationQuestionGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answers = undefined;
    this.label = undefined;
    this.labelledBy = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-accumulation-question-group-container');
    customElements.whenDefined('bp-sdk-external-accumulation-question-group-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-accumulation-question-group-container", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return h("bp-sdk-accumulation-question-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
};
BpSdkAccumulationQuestionGroupContainer.style = bpSdkAccumulationQuestionGroupContainerCss;

const bpSdkAddressGroupCss = "";

const BpSdkAddressGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.saveAnswer = createEvent(this, "saveAnswer", 7);
    this.addressMissingComponents = createEvent(this, "addressMissingComponents", 7);
    this.updateInputs = (address) => () => {
      this.updateStreet(address);
      this.updateCity(address);
      this.updateState(address);
      this.updateZip(address);
    };
    /**
     * Emits addressMissingComponents event if any required
     * address components are missing
     *
     * @param addressComponents The array of address components from Google
     */
    this.handleMissingAddressComponents = (addressComponents) => {
      const missingComponents = this.getMissingAddressComponents(addressComponents);
      if (missingComponents.length) {
        this.addressMissingComponents.emit({
          missing_components: missingComponents,
        });
      }
    };
    /**
     * Finds the address components that are missing in the Google data
     *
     * @param addressComponents The array of address components from Google
     * @returns Returns an array of missing address component types
     */
    this.getMissingAddressComponents = (addressComponents) => {
      const requiredAddressComponentTypes = ['street_number', 'route', 'locality', 'administrative_area_level_1', 'postal_code'];
      return requiredAddressComponentTypes.filter((requiredAddressComponentType) => {
        return !addressComponents.some((addressComponent) => addressComponent.types[0] === requiredAddressComponentType);
      });
    };
    this.answers = [];
    this.label = undefined;
    this.labelledBy = undefined;
    this.answerMap = {};
    this.useExternal = false;
  }
  onAnswersChange(newAnswers) {
    const map = {};
    newAnswers.forEach((answer) => {
      var _a;
      if ((_a = answer === null || answer === void 0 ? void 0 : answer.question) === null || _a === void 0 ? void 0 : _a.reference_type) {
        map[answer.question.reference_type] = answer;
      }
    });
    this.answerMap = map;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-address-group');
    customElements.whenDefined('bp-sdk-external-address-group').then(() => {
      this.useExternal = true;
    });
    this.onAnswersChange(this.answers);
  }
  emitSaveAnswer(answer, newValue) {
    this.saveAnswer.emit({
      answer,
      new_value: newValue,
    });
  }
  onPlacesUpdate({ detail }) {
    if (this.useExternal) {
      return;
    }
    const address = {};
    if (detail.address_components) {
      detail.address_components.forEach((addressComponent) => {
        address[addressComponent.types[0]] = {
          short: addressComponent.short_name,
          long: addressComponent.long_name,
        };
      });
      setTimeout(this.updateInputs(address), 0);
      this.handleMissingAddressComponents(detail.address_components);
    }
    this.updateJson(detail);
  }
  updateStreet(address) {
    if (address['street_number'] && address['route']) {
      const street_answer = this.answerMap['street_1'];
      if (street_answer) {
        this.emitSaveAnswer(Object.assign({}, street_answer), `${address['street_number'].long} ${address['route'].long}`);
      }
    }
  }
  updateCity(address) {
    if (address['locality']) {
      const city_answer = this.answerMap['city'];
      if (city_answer) {
        this.emitSaveAnswer(Object.assign({}, city_answer), address['locality'].long);
      }
    }
  }
  updateState(address) {
    if (address['administrative_area_level_1']) {
      const state_answer = this.answerMap['state'];
      if (state_answer) {
        const state = address['administrative_area_level_1'].short;
        const state_choice = state_answer.question.choices.find((choice) => choice.alias === state);
        if (state_choice) {
          this.emitSaveAnswer(Object.assign({}, state_answer), [state_choice.id]);
        }
      }
    }
  }
  updateZip(address) {
    if (address['postal_code']) {
      const zip_answer = this.answerMap['zipcode'];
      if (zip_answer) {
        this.emitSaveAnswer(Object.assign({}, zip_answer), address['postal_code'].long);
      }
    }
  }
  updateJson(place) {
    const json_answer = this.answerMap['address_json'];
    if (json_answer) {
      this.emitSaveAnswer(Object.assign({}, json_answer), JSON.stringify(place));
    }
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-address-group", { answers: this.answers, label: this.label, labelledBy: this.labelledBy });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-address-group__container" }, h("div", { class: "bp-sdk-address-group__streets" }, h("div", { class: "bp-sdk-row" }, this.answerMap['street_1'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-primary", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['street_1']), answer: this.answerMap['street_1'] })), this.answerMap['street_2'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-street-secondary", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['street_2']), answer: this.answerMap['street_2'] })))), h("div", { class: "bp-sdk-address-group__locality" }, h("div", { class: "bp-sdk-row" }, this.answerMap['city'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__city", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['city']), answer: this.answerMap['city'] })), this.answerMap['state'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__state", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['state']), answer: this.answerMap['state'], useSelectAlias: true })), this.answerMap['zipcode'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group__zipcode", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['zipcode']), answer: this.answerMap['zipcode'] })))), this.answerMap['address_json'] && (h("bp-sdk-dynamic-input-redux-container", { class: "bp-sdk-address-group-address__json", labelledBy: this.labelledBy, shouldHideLabel: TL(this.label, this.answerMap['address_json']), answer: this.answerMap['address_json'], hidden: true }))));
  }
  static get watchers() { return {
    "answers": ["onAnswersChange"]
  }; }
};
BpSdkAddressGroup.style = bpSdkAddressGroupCss;

const bpSdkCoverageGroupCss = "";

const BpSdkCoverageGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-coverage-group');
    customElements.whenDefined('bp-sdk-external-coverage-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-coverage-group", { questionGroup: this.questionGroup });
  }
  renderAnswer(answer) {
    var _a;
    const nestedGroupToRender = (_a = this.questionGroup.nestedGroupsWithAnswers) === null || _a === void 0 ? void 0 : _a.get(answer.id);
    return [
      !nestedGroupToRender && h("bp-sdk-dynamic-input-redux-container", { answer: answer, id: `bp-sdk-question-group__${answer.question.id}` }),
      nestedGroupToRender && h("bp-sdk-question-group-container", { questionGroup: nestedGroupToRender }),
    ];
  }
  renderInternal() {
    var _a, _b, _c;
    return (h("div", { class: "bp-sdk-coverage-group__container" }, h("bp-sdk-question-group-label", { labelId: (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.groupId, label: (_b = this.questionGroup) === null || _b === void 0 ? void 0 : _b.parentQuestionAnswer.question.text }), (_c = this.questionGroup) === null || _c === void 0 ? void 0 :
      _c.answers.map((answer) => this.renderAnswer(answer))));
  }
};
BpSdkCoverageGroup.style = bpSdkCoverageGroupCss;

const bpSdkDriverGroupCss = "";

const BpSdkDriverGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deleteItem = createEvent(this, "deleteItem", 7);
    this.slotId = oL(8);
    this.onToggleExpansion = () => {
      this.isExpanded = !this.isExpanded;
    };
    this.onDeleteButtonClick = () => this.deleteItem.emit();
    this.group = undefined;
    this.canDelete = false;
    this.errors = {};
    this.isDriverValid = true;
    this.driverName = '';
    this.labelId = oL(8);
    this.useExternal = false;
    this.isExpanded = true;
  }
  onGroupChange(group) {
    this.updateDriverValidity(group, this.errors);
    this.updateDriverName(group);
  }
  onErrorsChange(errors) {
    this.updateDriverValidity(this.group, errors);
  }
  updateDriverName(group) {
    var _a, _b, _c, _d, _e, _f;
    if (!group) {
      return;
    }
    const firstName = (_b = (_a = yL('mqs_driver_first_name', group.answers)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : '';
    const lastName = (_d = (_c = yL('mqs_driver_last_name', group.answers)) === null || _c === void 0 ? void 0 : _c.value) !== null && _d !== void 0 ? _d : '';
    let name = group.label;
    if (firstName && lastName) {
      name = `${firstName} ${lastName}`;
    }
    if ((_e = group.parentQuestionAnswer) === null || _e === void 0 ? void 0 : _e.value) {
      name = (_f = group.parentQuestionAnswer) === null || _f === void 0 ? void 0 : _f.value;
    }
    this.driverName = name || 'Driver';
  }
  updateDriverValidity(group, errors) {
    var _a;
    this.isDriverValid = A4(group) && !!((_a = group.answers) === null || _a === void 0 ? void 0 : _a.reduce((acc, answer) => { var _a; return acc && !((_a = errors[answer.question.id]) === null || _a === void 0 ? void 0 : _a.length); }, true));
  }
  resetState() {
    this.driverName = '';
    this.isDriverValid = true;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-group');
    customElements.whenDefined('bp-sdk-external-driver-group').then(() => {
      this.useExternal = true;
    });
    this.updateDriverValidity(this.group, this.errors);
    this.updateDriverName(this.group);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-driver-group", { group: this.group, errors: this.errors, canDelete: this.canDelete });
  }
  renderInternal() {
    var _a;
    const iconName = this.isDriverValid ? 'person' : 'error-outline';
    return (h("div", { class: "bp-sdk-driver-group__container" }, h("bp-sdk-icon-container", { name: iconName }), h("span", { id: this.labelId, class: "bp-sdk-driver-group__name", slot: `${this.slotId}-label`, onClick: this.onToggleExpansion }, this.driverName), this.canDelete && (h("button", { type: "button", class: "bp-sdk-driver-group__delete-button", slot: `${this.slotId}-label--after`, onClick: this.onDeleteButtonClick }, "Delete")), h("bp-sdk-dynamic-input-list", { answers: (_a = this.group) === null || _a === void 0 ? void 0 : _a.answers, labelledBy: this.labelId })));
  }
  static get watchers() { return {
    "group": ["onGroupChange"],
    "errors": ["onErrorsChange"]
  }; }
};
BpSdkDriverGroup.style = bpSdkDriverGroupCss;

const bpSdkDriverQuestionPoolContainerCss = "";

const BpSdkDriverQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
        questionSets: getQuestionSets(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
    this.questionGroup = undefined;
    this.applicationId = undefined;
    this.config = undefined;
    this.questionSets = [];
    this.useExternal = false;
    this.questionPool = undefined;
    this.questionPoolId = undefined;
    this.isDeleting = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-pool-container');
    customElements.whenDefined('bp-sdk-external-driver-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-driver-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup, questionSets: this.questionSets }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-driver-question-pool-container__container" }, !this.isDeleting && !!this.questionPoolId && (h("bp-sdk-driver-group", { group: this.questionGroup, canDelete: true, onDeleteItem: this.handleDeleteItem }))));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkDriverQuestionPoolContainer.style = bpSdkDriverQuestionPoolContainerCss;

const bpSdkQuestionGroupLabelCss = "";

const BpSdkQuestionGroupLabel = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.labelId = undefined;
    this.label = undefined;
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-label');
    customElements.whenDefined('bp-sdk-external-question-group-label').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-group-label", { label: this.label, labelId: this.labelId });
  }
  renderInternal() {
    return (h("h2", { id: this.labelId, class: "bp-sdk-question-group__label" }, this.label));
  }
};
BpSdkQuestionGroupLabel.style = bpSdkQuestionGroupLabelCss;

const bpSdkStepperGroupCss = "";

const BpSdkStepperGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.questionGroup = undefined;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group');
    customElements.whenDefined('bp-sdk-external-stepper-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderAnswers(questionGroup) {
    var _a;
    return (_a = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.answers) === null || _a === void 0 ? void 0 : _a.map((answer) => {
      if (this.displayAsQuestionGroup(answer.id)) {
        const nestedGroup = this.questionGroup.nestedGroupsWithAnswers.get(answer.id);
        if (nestedGroup.answers.length > 0) {
          return h("bp-sdk-stepper-group", { questionGroup: nestedGroup });
        }
        return h("bp-sdk-stepper-group", { questionGroup: this.questionGroup.nestedGroupsWithAnswers.get(answer.id) });
      }
      else {
        return (h("bp-sdk-dynamic-input-redux-container", { answer: answer, labelledBy: "", id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" }));
      }
    });
  }
  renderExternal() {
    return h("bp-sdk-external-stepper-group", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    return h("div", { class: "bp-sdk-stepper-group__container" }, this.renderAnswers(this.questionGroup));
  }
  displayAsQuestionGroup(id) {
    return this.questionGroup.nestedGroupsWithAnswers.has(id);
  }
};
BpSdkStepperGroup.style = bpSdkStepperGroupCss;

const bpSdkStepperGroupButtonCss = "";

const BpSdkStepperGroupButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.answer = undefined;
    this.direction = undefined;
    this.buttonDisabled = false;
    this.handleStepperButtonClick = undefined;
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group-button');
    customElements.whenDefined('bp-sdk-external-stepper-group-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-stepper-group-button", { answer: this.answer, direction: this.direction, buttonDisabled: this.buttonDisabled, handleStepperButtonClick: this.handleStepperButtonClick }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-stepper-group-button__container" }, this.answer && (h("button", { type: "button", class: "bp-sdk-stepper-group-button__button", disabled: this.buttonDisabled, onClick: () => this.handleStepperButtonClick(this.answer, this.direction) }, this.answer.question.text))));
  }
};
BpSdkStepperGroupButton.style = bpSdkStepperGroupButtonCss;

const bpSdkStepperGroupContainerCss = "";

const BpSdkStepperGroupContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.handleStepperClick = (answerId) => {
      const index = this.questionGroup.answers.findIndex((answer) => answer.id === answerId);
      this.currentActiveStepper = index >= 0 ? index : 0;
    };
    this.handleButtonClick = (answerId, direction) => {
      if (direction === 'forward') {
        this.currentActiveStepper += 1;
      }
      else {
        this.currentActiveStepper -= 1;
      }
    };
    this.questionGroup = undefined;
    this.currentActiveStepper = 0;
    this.currentActiveStepperId = undefined;
    this.previousStep = null;
    this.nextStep = null;
    this.buttonDisable = false;
    this.useExternal = false;
  }
  onCurrentActiveStepChange(index) {
    var _a, _b, _c, _d, _e, _f;
    this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[index]) === null || _b === void 0 ? void 0 : _b.id;
    this.previousStep = (_d = (_c = this.questionGroup) === null || _c === void 0 ? void 0 : _c.answers[index - 1]) !== null && _d !== void 0 ? _d : null;
    this.nextStep = (_f = (_e = this.questionGroup) === null || _e === void 0 ? void 0 : _e.answers[index + 1]) !== null && _f !== void 0 ? _f : null;
    this.updateButtonDisabled();
  }
  onQuestionGroupChange(questionGroup) {
    var _a, _b;
    if (!!questionGroup) {
      this.currentActiveStepperId = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper]) === null || _b === void 0 ? void 0 : _b.id;
      this.updateButtonDisabled();
    }
  }
  resetState() {
    var _a, _b;
    this.currentActiveStepper = 0;
    this.previousStep = null;
    this.nextStep = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.answers[this.currentActiveStepper + 1]) !== null && _b !== void 0 ? _b : null;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-stepper-group-container');
    customElements.whenDefined('bp-sdk-external-stepper-group-container').then(() => {
      this.useExternal = true;
    });
    this.onCurrentActiveStepChange(this.currentActiveStepper);
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderCurrentQuestionGroup(currentActiveStepperId) {
    var _a;
    const currentGroup = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(currentActiveStepperId);
    return (h("div", { class: "bp-sdk-stepper-group-container__current-group" }, h("bp-sdk-stepper-group", { questionGroup: currentGroup })));
  }
  renderExternal() {
    return h("bp-sdk-external-stepper-group-container", { questionGroup: this.questionGroup });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-stepper-group-container__container" }, this.renderCurrentQuestionGroup(this.currentActiveStepperId), h("bp-sdk-stepper-group-button", { answer: this.previousStep, direction: "backward", buttonDisabled: false, handleStepperButtonClick: this.handleButtonClick }), h("bp-sdk-stepper-group-button", { answer: this.nextStep, direction: "forward", buttonDisabled: this.buttonDisable, handleStepperButtonClick: this.handleButtonClick })));
  }
  updateButtonDisabled() {
    var _a;
    if (!!this.currentActiveStepperId) {
      const group = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.nestedGroupsWithAnswers.get(this.currentActiveStepperId);
      const aggregateAnswers = [
        ...group.answers,
        ...group.answers.filter((answer) => {
          if (group.nestedGroupsWithAnswers.has(answer.id)) {
            return group.nestedGroupsWithAnswers.get(answer.id).answers;
          }
        }),
      ];
      this.buttonDisable = !aggregateAnswers.every((answer) => { var _a; return !!answer.choice_id || ((_a = answer.choice_ids) === null || _a === void 0 ? void 0 : _a.length) > 0 || !!answer.value || !answer.required || answer.display_type === 'private'; });
    }
  }
  static get watchers() { return {
    "currentActiveStepper": ["onCurrentActiveStepChange"],
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkStepperGroupContainer.style = bpSdkStepperGroupContainerCss;

const bpSdkVehiclePanelContainerCss = "";

const BpSdkVehiclePanelContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deleteItem = createEvent(this, "deleteItem", 7);
    this.saveAnswer = createEvent(this, "saveAnswer", 7);
    this.makeDisplayValue = '';
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, {
          loadYears,
          loadMakes,
          loadModels,
          loadConfigurations,
          loadSingleQuestionSet,
          loadSingleApplicationForm,
          selectVehicle,
          resetSelectedVehicle,
          loadFullVehicleOptions,
          setVehicleSelection,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        config: getPartnerEngineConfig(state),
        appFormId: state.application.form.id,
        yearOptions: getVehicleOptionsYears(state, this.questionGroupId),
        selectionStatus: getVehicleSelectionState(state, this.questionGroupId),
        vehicleInformation: getDisplayFriendlyVehicleOptionsSelection(state, this.questionGroupId),
      };
    };
    this.loadOptions = debounce_1((selection) => {
      this.loadFullVehicleOptions({
        year: selection.yearId,
        makeId: selection.makeId,
        modelId: selection.modelId,
        config: this.config,
        questionGroupId: this.questionGroupId,
        type: this.type,
      });
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection,
      });
    }, 100);
    this.setOptions = debounce_1((selection) => {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: Object.assign({ configurationId: undefined, makeId: undefined, modelId: undefined, yearId: undefined }, selection),
      });
    }, 100);
    this.onVehicleSaveCallback = () => {
      this.isSaving = false;
      this.isEditing = false;
      this.onQuestionGroupChange(this.questionGroup);
    };
    this.editVehicle = (e) => {
      e.stopPropagation();
      this.onEdit();
    };
    this.deleteVehicle = () => {
      this.deleteItem.emit(this.code);
    };
    this.onOpen = () => {
      this.canEdit = true;
      this.isEditing = false;
      this.isExpanded = true;
    };
    this.onClose = () => {
      this.canEdit = false;
      this.isEditing = false;
      this.isExpanded = false;
    };
    this.code = undefined;
    this.answers = [];
    this.questionGroup = undefined;
    this.canDelete = false;
    this.appFormId = undefined;
    this.config = undefined;
    this.yearOptions = {};
    this.selectionStatus = undefined;
    this.shouldShowTrailers = false;
    this.isVehicleTrailer = false;
    this.vehicleInformation = {
      year: '',
      make: '',
      model: '',
      configuration: '',
    };
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isSaving = false;
    this.isValid = true;
    this.useExternal = false;
    this._currentYear = undefined;
    this._currentMakeId = undefined;
    this._currentModelId = undefined;
    this._currentConfigId = undefined;
    this.questionGroupId = undefined;
    this.type = undefined;
    this.tabIndex = 0;
    this.vehicleLabel = '';
  }
  resetState() {
    this.canEdit = true;
    this.canSave = false;
    this.isEditing = false;
    this.isExpanded = true;
    this.isValid = true;
    this.type = undefined;
    this.vehicleLabel = '';
    this.makeDisplayValue = '';
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-panel-container');
    customElements.whenDefined('bp-sdk-external-vehicle-panel-container').then(() => {
      this.useExternal = true;
    });
    this.onIsVehicleTrailerChanged(this.isVehicleTrailer);
    this.onTabChanged(this.tabIndex);
    this.onQuestionGroupChange(this.questionGroup);
  }
  handleTabChanged({ detail }) {
    if (this.useExternal) {
      return;
    }
    this.tabIndex = detail;
  }
  onTabChanged(tab) {
    this.updateType(tab, this.isVehicleTrailer);
  }
  onIsVehicleTrailerChanged(isVehicleTrailer) {
    this.updateType(this.tabIndex, isVehicleTrailer);
  }
  updateType(tab, isVehicleTrailer) {
    if (this.useExternal) {
      return;
    }
    const type = isVehicleTrailer || this.isTrailerTab(tab) ? w.trailers : undefined;
    if (type !== this.type) {
      this.setVehicleSelection({
        questionGroupId: this.questionGroupId,
        selection: { yearId: undefined, modelId: undefined, makeId: undefined, configurationId: undefined },
      });
      this.populateVehicleOptions(this.questionGroup);
      this.type = type;
      this.fetchYears();
    }
  }
  isTrailerTab(tab) {
    var _a;
    const flow = ac(this.questionGroup);
    const trailerTab = flow === null || flow === void 0 ? void 0 : flow.question.choices.find((choice) => !!choice.value.match(/trailer/gi));
    const order = (_a = trailerTab === null || trailerTab === void 0 ? void 0 : trailerTab.order) !== null && _a !== void 0 ? _a : 2; // we know what order should be
    return tab === order;
  }
  populateVehicleOptions(questionGroup) {
    var _a, _b, _c, _d;
    const existingVehicleAnswer = (_a = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.answers) === null || _a === void 0 ? void 0 : _a.find((ans) => ans.question.reference_type === c.CommercialAutoJson);
    if (!(existingVehicleAnswer === null || existingVehicleAnswer === void 0 ? void 0 : existingVehicleAnswer.value)) {
      return;
    }
    const vehicleJson = JSON.parse(existingVehicleAnswer.value);
    let year = Number(vehicleJson.year);
    let makeId = (_b = vehicleJson.make_id) === null || _b === void 0 ? void 0 : _b.toString();
    let modelId = (_c = vehicleJson.model_id) === null || _c === void 0 ? void 0 : _c.toString();
    let configurationId = (_d = vehicleJson.configuration_id) === null || _d === void 0 ? void 0 : _d.toString();
    let isFreeformTrailer = false;
    //account for fallthrough free-text values for trailers
    if (vehicleJson.category === 'Trailers') {
      if (!makeId) {
        makeId = vehicleJson.make;
        isFreeformTrailer = true;
      }
      if (!modelId) {
        modelId = vehicleJson.model;
        isFreeformTrailer = true;
      }
    }
    const isValidState = !Number.isNaN(year) && makeId && modelId && (configurationId || vehicleJson.category === 'Trailers');
    this._currentYear = year;
    this._currentMakeId = makeId;
    this._currentModelId = modelId;
    this._currentConfigId = configurationId;
    this.canSave = this.isVehicleInputComplete();
    if (isValidState && !isFreeformTrailer) {
      this.loadOptions({
        yearId: year,
        makeId,
        modelId,
        configurationId,
      });
    }
  }
  onQuestionGroupChange(questionGroup, oldQuestionGroup) {
    if (this.isSaving || isEqual_1(questionGroup, oldQuestionGroup)) {
      return;
    }
    this.questionGroupId = $9(questionGroup);
    const oldGroupId = $9(oldQuestionGroup);
    if (this.questionGroupId !== oldGroupId)
      this.populateVehicleOptions(questionGroup);
    this.handleSubscriptions();
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  onVehicleInformationChange(vehicleInformation) {
    this.isValid = !!(vehicleInformation.make && vehicleInformation.model && vehicleInformation.year);
  }
  onOptionsUpdate(updateEvent) {
    var _a;
    const data = updateEvent.detail;
    if (!(data === null || data === void 0 ? void 0 : data.value)) {
      return;
    }
    switch (data.type) {
      case R.Year:
        const currentYear = Number(data.value);
        if (!Number.isNaN(currentYear) && currentYear) {
          this._currentYear = currentYear;
          this._currentMakeId = undefined;
          this._currentModelId = undefined;
          this._currentConfigId = undefined;
          this.setOptions({ yearId: currentYear });
          this.fetchMakes();
        }
        break;
      case R.Make:
        this._currentMakeId = data.value;
        this._currentModelId = undefined;
        this._currentConfigId = undefined;
        this.setOptions({ makeId: this._currentMakeId, yearId: this._currentYear });
        if (!data.freeform)
          this.fetchModels();
        // Needed for free-form answer flows for trailers
        this.makeDisplayValue = (_a = data.displayValue) !== null && _a !== void 0 ? _a : '';
        break;
      case R.Model:
        this._currentModelId = data.value;
        this._currentConfigId = undefined;
        this.setOptions({
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        if (!data.freeform)
          this.fetchConfigurations();
        break;
      case R.Configuration:
        this._currentConfigId = data.value;
        this.setOptions({
          configurationId: this._currentConfigId,
          modelId: this._currentModelId,
          makeId: this._currentMakeId,
          yearId: this._currentYear,
        });
        break;
    }
    this.vehicleLabel = this.getVehicleLabel();
    this.canSave = this.isVehicleInputComplete();
  }
  fetchYears() {
    this.loadYears({ config: this.config, questionGroupId: this.questionGroupId });
  }
  fetchMakes() {
    this.loadMakes({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
    });
  }
  fetchModels() {
    this.loadModels({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
    });
  }
  fetchConfigurations() {
    this.loadConfigurations({
      config: this.config,
      questionGroupId: this.questionGroupId,
      type: this.type,
      year: this._currentYear,
      makeId: this._currentMakeId,
      modelId: this._currentModelId,
    });
  }
  onMakeDirty() {
    if (!this.isValid && !this.isEditing && this.canEdit) {
      this.onEdit();
      setTimeout(() => pL(), 200);
    }
  }
  onVinUpdate(event) {
    const answer = this.questionGroup.answers.find((ans) => ans.id === event.detail.answerId);
    if (answer != null) {
      this.saveAnswer.emit({ answer, new_value: event.detail.vin });
    }
  }
  onVehicleSave(saveEvent) {
    const flowType = saveEvent.detail;
    const isTrailerFlow = flowType === N.trailers;
    const type = isTrailerFlow ? N.trailers : undefined;
    const params = {
      answerPoolId: this.questionGroup.poolId,
      appId: this.appFormId,
      questionGroupId: this.questionGroup.groupId,
      configurationId: this._currentConfigId,
      flowType,
      config: this.config,
      type,
      callback: this.onVehicleSaveCallback,
    };
    if (flowType && (isTrailerFlow || this._currentConfigId)) {
      this.isSaving = true;
      if (isTrailerFlow && !this._currentConfigId) {
        /**
         * The vehicle params support the free-form text flow. They will be ignored if params.configurationId is defined.
         * In a free-form flow, PE uses the YMM values as-is, so we always need to pass them as the display values
         * instead of as IDs.
         *
         * The year id always matches the display value, so we can use that in any scenario.
         * If we are in a free-form flow, the model will always be a free-form answer. Therefore the id and display
         * values will match, and we can send the model id.
         * Make can be a dropdown option id or a free-form answer. If it is a dropdown option, the display value is the
         * text value we need to send to PE. If it is a free-form answer, the display value will match the id, and either
         * can be sent to PE. Therefore, we can safely choose the display value for either scenario.
         */
        params.vehicle = {
          yearId: this._currentYear,
          makeId: this.makeDisplayValue,
          modelId: this._currentModelId,
        };
      }
      this.selectVehicle(params);
    }
  }
  onVehicleResourceChange(vehicleSelectionState) {
    if (this.isEditing) {
      switch (vehicleSelectionState) {
        case s.Loaded:
          this.resetSelectedVehicle({ questionGroupId: this.questionGroup.groupId });
          break;
      }
    }
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onEdit() {
    if (!this.yearOptions || !Object.keys(this.yearOptions).length) {
      this.fetchYears();
    }
    this.isEditing = true;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-panel-container", { answers: this.answers, appFormId: this.appFormId, canDelete: this.canDelete, code: this.code, config: this.config, isVehicleTrailer: this.isVehicleTrailer, questionGroup: this.questionGroup, selectionStatus: this.selectionStatus, shouldShowTrailers: this.shouldShowTrailers, yearOptions: this.yearOptions, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  renderInternal() {
    return (h("bp-sdk-vehicle-panel", { answers: this.answers, canDelete: this.canDelete, canEdit: this.canEdit, canSave: this.canSave, code: this.code, handleClose: this.onClose, handleDelete: this.deleteVehicle, handleEdit: this.editVehicle, handleOpen: this.onOpen, isEditing: this.isEditing, isExpanded: this.isExpanded, isValid: this.isValid, questionGroup: this.questionGroup, isVehicleTrailer: this.isVehicleTrailer, shouldShowTrailers: this.shouldShowTrailers, vehicleInformation: this.vehicleInformation, vehicleLabel: this.vehicleLabel }));
  }
  getVehicleLabel() {
    var _a, _b, _c;
    // This is the anchor question. Its value should be the full vehicle name
    return (_c = (_b = (_a = this.questionGroup) === null || _a === void 0 ? void 0 : _a.parentQuestionAnswer) === null || _b === void 0 ? void 0 : _b.value) !== null && _c !== void 0 ? _c : '';
  }
  isVehicleInputComplete() {
    const hasTrailerValues = !!this._currentYear && !!this._currentMakeId && !!this._currentModelId;
    const canSaveTrailer = this.isVehicleTrailer && hasTrailerValues && (!!this._currentConfigId || this.isFreeFill());
    return canSaveTrailer || !!this._currentConfigId;
  }
  isFreeFill() {
    return isNaN(+this._currentModelId);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "tabIndex": ["onTabChanged"],
    "isVehicleTrailer": ["onIsVehicleTrailerChanged"],
    "questionGroup": ["onQuestionGroupChange"],
    "vehicleInformation": ["onVehicleInformationChange"],
    "selectionStatus": ["onVehicleResourceChange"]
  }; }
};
BpSdkVehiclePanelContainer.style = bpSdkVehiclePanelContainerCss;

const bpSdkVehicleQuestionPoolContainerCss = "";

const BpSdkVehicleQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
    this.questionGroup = undefined;
    this.applicationId = undefined;
    this.config = undefined;
    this.useExternal = false;
    this.questionPool = undefined;
    this.questionPoolId = undefined;
    this.isDeleting = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-question-pool-container');
    customElements.whenDefined('bp-sdk-external-vehicle-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup }));
  }
  renderInternal() {
    return (!this.isDeleting &&
      !!this.questionPoolId && (h("bp-sdk-vehicle-panel-container", { canDelete: true, isVehicleTrailer: b9(this.questionGroup), onDeleteItem: this.handleDeleteItem, questionGroup: this.questionGroup, answers: o4(this.questionGroup), shouldShowTrailers: this.questionGroup.order >= 1 || b9(this.questionGroup) })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkVehicleQuestionPoolContainer.style = bpSdkVehicleQuestionPoolContainerCss;

export { BpSdkAccordion as bp_sdk_accordion, BpSdkAccumulationQuestionGroup as bp_sdk_accumulation_question_group, BpSdkAccumulationQuestionGroupContainer as bp_sdk_accumulation_question_group_container, BpSdkAddressGroup as bp_sdk_address_group, BpSdkCoverageGroup as bp_sdk_coverage_group, BpSdkDriverGroup as bp_sdk_driver_group, BpSdkDriverQuestionPoolContainer as bp_sdk_driver_question_pool_container, BpSdkQuestionGroupLabel as bp_sdk_question_group_label, BpSdkStepperGroup as bp_sdk_stepper_group, BpSdkStepperGroupButton as bp_sdk_stepper_group_button, BpSdkStepperGroupContainer as bp_sdk_stepper_group_container, BpSdkVehiclePanelContainer as bp_sdk_vehicle_panel_container, BpSdkVehicleQuestionPoolContainer as bp_sdk_vehicle_question_pool_container };
