import { r as registerInstance, c as createEvent, h as h$1 } from './index-8f8983b3.js';
import { saveQuestionSet, updateErrors, removeActiveAnswerId, switchActiveQuestionSet, pushAnswer, getEligibilityResults, getCurrentActiveQuestionSet, getFormId, getPartnerEngineConfig, getAnswersState, getApplicationFormState, getQuestionPoolState, getQuestionSetState, selectQuestionSetsState, selectIsActiveQuestionSetPendingProcess, doesUserOwnApplicationForm, userHasPermission } from '@boldpenguin/sdk-redux';
import { S, h, s, n as ne } from './index.esm.min-44aaacc7.js';
import { b as bc, $ as $c, y as ya, p as pL, m as ma, x as x4, O as O4, a as xl } from './index.esm.min-11fd4158.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';

const bpSdkNextButtonContainerCss = "";

const BpSdkNextButtonContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.bpAnalyticsTrack = createEvent(this, "bpAnalyticsTrack", 7);
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        if (this.storeUnsubscribe) {
          this.storeUnsubscribe();
        }
        store.mapDispatchToProps(this, {
          saveQuestionSet,
          updateErrors,
          removeActiveAnswerId,
          switchActiveQuestionSet,
          pushAnswer,
          getEligibilityResults,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => ({
      activeQuestionSet: getCurrentActiveQuestionSet(state),
      applicationId: getFormId(state),
      config: getPartnerEngineConfig(state),
      answersResourceState: getAnswersState(state),
      applicationFormResourceState: getApplicationFormState(state),
      pendingProcesses: state.application.pendingProcesses,
      questionPoolResourceState: getQuestionPoolState(state),
      questionSetResourceState: getQuestionSetState(state),
      questionSetState: selectQuestionSetsState(state),
      queue: state.queues.answers.queue,
      enableUserApplicationGuard: !!state.config.options.enableUserApplicationGuard,
      locked: state.application.form.locked,
      isActiveQuestionSetPendingProcess: selectIsActiveQuestionSetPendingProcess(state),
      isOwner: doesUserOwnApplicationForm(state),
      hasPermissionToEdit: userHasPermission(state, {
        permission: S.ApplicationForms,
        action: h.Update,
      }),
    });
    this.activeQuestionSet = undefined;
    this.buttonDisabled = false;
    this.config = undefined;
    this.queue = undefined;
    this.shouldDisableIfIncomplete = false;
    this.answersResourceState = undefined;
    this.applicationFormResourceState = undefined;
    this.questionPoolResourceState = undefined;
    this.questionSetResourceState = undefined;
    this.questionSetState = undefined;
    this.locked = undefined;
    this.pendingProcesses = undefined;
    this.isOwner = undefined;
    this.hasPermissionToEdit = undefined;
    this.isActiveQuestionSetPendingProcess = undefined;
    this.enableUserApplicationGuard = undefined;
    this.applicationId = undefined;
    this.useExternal = false;
    this.canSave = true;
    this.areResourcesReady = true;
    this.isDisabled = false;
    this.caDisabled = false;
    this.isReady = true;
    this.isLocked = false;
    this.isFirstRun = true;
    this.classes = '';
  }
  resetState() {
    this.isReady = true;
    this.isFirstRun = true;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-next-button-container');
    customElements.whenDefined('bp-sdk-external-next-button-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onShouldDisableIfIncompleteChange(this.shouldDisableIfIncomplete);
    this.onAnswersResourcesStateChange(this.answersResourceState);
    this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
    this.onHasPermissionToEdit(this.hasPermissionToEdit);
    this.onEnableUserApplicationGuard(this.enableUserApplicationGuard);
    this.onIsFirstRun(this.isFirstRun);
    this.onIsOwner(this.isOwner);
    this.onIsReady(this.isReady);
    this.onLocked(this.locked);
    this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
    this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
    this.onQueueChange(this.queue);
    this.onIsActiveQuestionSetPendingProcess(this.isActiveQuestionSetPendingProcess);
  }
  onEnableUserApplicationGuard(enableUserApplicationGuard) {
    this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, enableUserApplicationGuard);
  }
  onHasPermissionToEdit(hasPermission) {
    this.updateIsLocked(this.locked, this.isOwner, hasPermission, this.enableUserApplicationGuard);
  }
  onIsOwner(isOwner) {
    this.updateIsLocked(this.locked, isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  onLocked(locked) {
    this.updateIsLocked(locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  updateIsLocked(locked, isOwner, hasPermission, enableUserApplicationGuard) {
    this.isLocked = locked || (enableUserApplicationGuard && (!isOwner || !hasPermission));
  }
  onIsFirstRun(isFirstRun) {
    this.updateAreResourcesReady(isFirstRun, this.isReady);
  }
  onIsReady(isReady) {
    this.updateAreResourcesReady(this.isFirstRun, isReady);
  }
  updateAreResourcesReady(isFirstRun, isReady) {
    this.areResourcesReady = isFirstRun || isReady;
  }
  onAnswersResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: state,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onApplicationFormResourceStateChange(state) {
    if (this.isFirstRun && state === s.Loaded) {
      this.isFirstRun = false;
    }
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: state,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionPoolResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: state,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionSetResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: state,
    });
  }
  calculateResourcesReady(resources = {}) {
    if (!resources ||
      resources.applicationForm !== s.Loaded ||
      resources.answers === s.Loading ||
      resources.questionPools === s.Loading ||
      resources.questionSets === s.Loading) {
      return false;
    }
    return true;
  }
  onShouldDisableIfIncompleteChange(shouldDisableIfIncomplete) {
    this.updateOnDisableIfIncomplete(shouldDisableIfIncomplete, this.activeQuestionSet);
  }
  onActiveQuestionSetChange(activeQuestionSet) {
    this.updateOnDisableIfIncomplete(this.shouldDisableIfIncomplete, activeQuestionSet);
    this.disableIfCAQuestionSet(this.shouldDisableIfIncomplete, activeQuestionSet);
  }
  onQueueChange(queue) {
    this.canSave = !(queue === null || queue === void 0 ? void 0 : queue.length) && !this.isActiveQuestionSetPendingProcess;
  }
  onIsActiveQuestionSetPendingProcess(isQSPending) {
    this.canSave = !isQSPending;
  }
  disableIfCAQuestionSet(shouldDisableIfIncomplete, activeQuestionSet) {
    let shouldDisable = false;
    if (shouldDisableIfIncomplete && activeQuestionSet) {
      shouldDisable = bc(activeQuestionSet);
    }
    if (this.caDisabled !== shouldDisable) {
      this.caDisabled = shouldDisable;
    }
  }
  updateOnDisableIfIncomplete(shouldDisableIfIncomplete, activeQuestionSet) {
    this.isDisabled = shouldDisableIfIncomplete && this.isDisabledStatusByActiveQuestionSet(activeQuestionSet);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h$1("bp-sdk-external-next-button-container", { activeQuestionSet: this.activeQuestionSet, answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, applicationId: this.applicationId, buttonDisabled: this.buttonDisabled, config: this.config, enableUserApplicationGuard: this.enableUserApplicationGuard, hasPermissionToEdit: this.hasPermissionToEdit, isOwner: this.isOwner, locked: this.locked, pendingProcesses: this.pendingProcesses, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSetState: this.questionSetState, queue: this.queue, shouldDisableIfIncomplete: this.shouldDisableIfIncomplete }));
  }
  handleSaveQuestionSet() {
    if (this.shouldCallSaveQuestionSet()) {
      const invalidAnswers = this.activeQuestionSet.answers.filter((answer) => !$c(answer));
      if (!invalidAnswers.length && this.isNextButtonClickable()) {
        this.removeActiveAnswerId();
        if (!this.activeQuestionSet.parentQuestionSetId) {
          this.callSaveQuestionSet();
        }
        else {
          if (this.parentQuestionSetCanSave()) {
            this.callSaveQuestionSet(true);
          }
          else {
            this.handleStep();
          }
        }
      }
      else {
        invalidAnswers.forEach((answer) => {
          this.updateErrors({ answer, errors: ya(answer) });
        });
        pL();
      }
    }
    else if (this.isNextButtonClickable()) {
      this.switchActiveQuestionSet('forward');
    }
  }
  renderInternal() {
    return (h$1("bp-sdk-next-button", { buttonDisabled: !this.isNextButtonClickable(), cssClasses: !this.areResourcesReady || !this.canSave ? 'loading' : 'not-loading' }));
  }
  parentQuestionSetCanSave() {
    const parentQuestionSet = this.questionSetState.parentQuestionSets.find((pqs) => pqs.id === this.activeQuestionSet.parentQuestionSetId);
    if (parentQuestionSet) {
      return this.questionSetState.list
        .filter((qs) => qs.parentQuestionSetId === parentQuestionSet.id)
        .every((qs) => ma(qs.answers));
    }
  }
  callSaveQuestionSet(useParent = false) {
    this.saveQuestionSet({
      config: this.config,
      appFormQuestionSet: this.activeQuestionSet,
      navigationDirection: 'forward',
      parentQuestionSet: useParent
        ? this.questionSetState.parentQuestionSets.find((pqs) => pqs.id === this.activeQuestionSet.parentQuestionSetId)
        : undefined,
    });
    this.bpAnalyticsTrack.emit({
      eventName: ne.QuestionSetSaved,
      eventPayload: {
        applicationFormQuestionSetId: this.activeQuestionSet.id,
        questionSetId: this.activeQuestionSet.question_set_id,
        questionSetCode: this.activeQuestionSet.question_set.code,
      },
    });
  }
  handleStep() {
    const parent = x4(this.activeQuestionSet, this.questionSetState);
    const newValue = O4(this.activeQuestionSet);
    if (parent.value !== newValue) {
      this.pushAnswer(xl(parent, newValue));
    }
    this.getEligibilityResults({ appId: this.applicationId, config: this.config });
    this.switchActiveQuestionSet('forward');
  }
  isDisabledStatusByActiveQuestionSet(activeQuestionSet) {
    var _a;
    // If missing active question set then default to disable.
    if (!activeQuestionSet) {
      return true;
    }
    // If missing answers then default to enabled
    if (!activeQuestionSet.answers || ((_a = activeQuestionSet.answers) === null || _a === void 0 ? void 0 : _a.length) === 0) {
      return false;
    }
    // Else state determined by if all required answers are completed
    return activeQuestionSet.answers.some((answer) => !answer.is_completed && answer.required);
  }
  shouldCallSaveQuestionSet() {
    if (this.isLocked) {
      return false;
    }
    return !this.activeQuestionSet.is_completed || !!this.activeQuestionSet.parentQuestionSetId;
  }
  isNextButtonClickable() {
    return !this.buttonDisabled && this.areResourcesReady && this.canSave && !this.isDisabled && !this.caDisabled;
  }
  static get watchers() { return {
    "enableUserApplicationGuard": ["onEnableUserApplicationGuard"],
    "hasPermissionToEdit": ["onHasPermissionToEdit"],
    "isOwner": ["onIsOwner"],
    "locked": ["onLocked"],
    "isFirstRun": ["onIsFirstRun"],
    "isReady": ["onIsReady"],
    "answersResourceState": ["onAnswersResourcesStateChange"],
    "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
    "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
    "questionSetResourceState": ["onQuestionSetResourcesStateChange"],
    "shouldDisableIfIncomplete": ["onShouldDisableIfIncompleteChange"],
    "activeQuestionSet": ["onActiveQuestionSetChange"],
    "queue": ["onQueueChange"],
    "isActiveQuestionSetPendingProcess": ["onIsActiveQuestionSetPendingProcess"]
  }; }
};
BpSdkNextButtonContainer.style = bpSdkNextButtonContainerCss;

export { BpSdkNextButtonContainer as bp_sdk_next_button_container };
